@@ -11,6 +11,10 @@
 #' @export
 #' 
 das.merge.acoustic <- function(acoust.file, das.file, out.file) {
+  warning(
+    "This function is deprecated and will be removed in later versions. ",
+    "See https://github.com/smwoodman/swfscDAS for replacement functionality."
+  )
   das.df <- das.read(das.file)
   sight.df <- das.df[das.df$Event == "S", ]
   rownames(sight.df) <- sight.df$Sight
