@@ -8,6 +8,10 @@
 #' @export
 #' 
 das.spp.freq <- function(x) {
+  warning(
+    "This function is deprecated and will be removed in later versions. ",
+    "See https://github.com/smwoodman/swfscDAS for replacement functionality."
+  )
   df <- if(is.data.frame(x)) x else das.read(x)
   df <- df[df$Event == "A" & df$OnEffort, ]
   spp <- unlist(df[, c("Spp1", "Spp2", "Spp3")])
